@@ -471,13 +471,11 @@ class VacBot():
 
     def refresh_components(self):
         try:
-            print("COMPONENTS START")
             self.exc_command('getLifeSpan',[COMPONENT_TO_ECOVACS["brush"]])
             self.exc_command('getLifeSpan',[COMPONENT_TO_ECOVACS["sideBrush"]])
             self.exc_command('getLifeSpan',[COMPONENT_TO_ECOVACS["heap"]])
             self.exc_command('getCachedMapInfo')
             self.exc_command('GetCleanLogs')
-            print("COMPONENTS END")
         except XMPPError as err:
             _LOGGER.warning("Component refresh requests failed to reach VacBot. Will try again later.")
             _LOGGER.warning("*** Error type: " + err.etype)
@@ -485,14 +483,11 @@ class VacBot():
 
     def refresh_statuses(self):
         try:
-
-            print("STATUSES START")
             self.exc_command('getCleanInfo')
             self.exc_command('getChargeState')
             self.exc_command('getBattery')
             self.exc_command('getSpeed')
             self.exc_command('getWaterInfo')
-            print("STATUSES END")
         except XMPPError as err:
             _LOGGER.warning("Initial status requests failed to reach VacBot. Will try again on next ping.")
             _LOGGER.warning("*** Error type: " + err.etype)
@@ -500,21 +495,14 @@ class VacBot():
 
     def refresh_liveMap(self):
         try:
-            print("LIVE MAP START")
             self.exc_command('getMajorMap')
             self.live_map = self.Map.GetBase64Map()
-
-            print("LIVE MAP END")
         except XMPPError as err:
             _LOGGER.warning("Initial live map failed to reach VacBot. Will try again on next ping.")
             _LOGGER.warning("*** Error type: " + err.etype)
             _LOGGER.warning("*** Error condition: " + err.condition)
 
     def request_all_statuses(self):
-        print("THREAD STATUSES: " + str(self.thread_statuses.isAlive()))
-        print("THREAD LIVE MAP: " + str(self.thread_livemap.isAlive()))
-        print("THREAD COMPONENT: " + str(self.thread_components.isAlive()))
-
         if not self.thread_statuses.isAlive():
             self.thread_statuses = threading.Thread(target=self.refresh_statuses, daemon=False, name="schedule_thread_statuses")
             self.thread_statuses.start()
