@@ -202,10 +202,7 @@ def run(actions, debug):
             click.echo("performing " + str(action.vac_command))
 
             while True:
-                print("aaaa")
                 vacbot.request_all_statuses()
-                print("bbb")
-                print("Battery Status: " + str(vacbot.battery_status), end = '')
                 time.sleep(20)
 		
         for v in vacbot.rooms:
